//
// XMM Science Analysis System
//
// Giuseppe Vacanti (European Space Agency) 
// December 13, 1999
//
// $Id: sashelp.cc,v 1.4.2.1.2.1 2002/12/05 12:31:43 gvacanti Exp $
//
#include "sashelp.h"

#include <errstr.h>
#include <param.h>
#include <Tracer.h>
#include <SasFileLocator.h>

#include <string>
#include <vector>

using namespace std;

namespace {
  void browse(const std::string & url) {
    
    // Invoke a browser on the given url. By default it'll try to talk
    // to netscape. This can be changed with the environment variable
    // SAS_BROWSER.

    string browser("netscape");
    if(getenv("SAS_BROWSER"))
      browser = getenv("SAS_BROWSER");

    string command = browser + " " + url;

    if(system(command.c_str())){
      errstr << "I tried to view the document " + url + " with " + browser
	+ ". This operation failed. If you are sure of your browser settings via the environment variable SAS_BROWSER, you may try the command '"
	+ browser + " " + url + "' yourself to see what may be wrong. As a last resort option, try to view the file $SAS_DIR/README.html directly."
	     << Sas::error("HtmlBrowserFailed");
    }
  }
}


void sashelp () {
  PROC
    // There are two types of html files:
    //   + <subdir of SAS_PATH>/doc/<something>.html
    //   + <subdir of SAS_PATH>/doc/<something>/index.html
  string s = stringParameter("doc");
  const string readmetarget = "README.html";
  const string toptarget = "doc/" + s + ".html";
  const string tasktarget = "doc/" + s + "/" + "index.html";
  string readmedoc = fileLocator.locate(readmetarget, "", false);
  string topdoc = fileLocator.locate(toptarget, "", false);
  string taskdoc = fileLocator.locate(tasktarget, "", false);
  if(topdoc.size() > 0){
    browse("file://" + topdoc);
    if(taskdoc.size() > 0){
      clog << "Found two matching documents. Opening both of them." << endl;
      browse("file://" + taskdoc);
    }
  } else if(taskdoc.size() > 0) {
    browse("file://" + taskdoc);
  } else if(readmedoc.size() > 0) {
    if(s != readmetarget)
      clog << "I could fine no document matching " + s + ". Going for the default SAS page." << endl;
    browse("file://" + readmedoc);
  } else {
    errstr << "Could not find any suitable documentation matching " + s + "."
	   << Sas::error("NoHtmlDocument");
  }
}
  
  
